==> fet_5.5.5.orig.tar.gz: fet-5.5.5/src/interface/constraintteachermaxbuildingchangesperweekform.h <==
/***************************************************************************
                          constraintteachermaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERMAXBUILDINGCHANGESPERWEEKFORM_H
#define CONSTRAINTTEACHERMAXBUILDINGCHANGESPERWEEKFORM_H

#include "constraintteachermaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>
#include <q3listbox.h>

class ConstraintTeacherMaxBuildingChangesPerWeekForm : public ConstraintTeacherMaxBuildingChangesPerWeekForm_template  {
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintTeacherMaxBuildingChangesPerWeekForm();
	~ConstraintTeacherMaxBuildingChangesPerWeekForm();

	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();

	bool filterOk(SpaceConstraint* ctr);
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/constraintteachermaxbuildingchangesperweekform.h <==
/***************************************************************************
                          constraintteachermaxbuildingchangesperweekform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONSTRAINTTEACHERMAXBUILDINGCHANGESPERWEEKFORM_H
#define CONSTRAINTTEACHERMAXBUILDINGCHANGESPERWEEKFORM_H

#include "ui_constraintteachermaxbuildingchangesperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>
#include <q3listbox.h>

class ConstraintTeacherMaxBuildingChangesPerWeekForm : public QDialog, Ui::ConstraintTeacherMaxBuildingChangesPerWeekForm_template  {
	Q_OBJECT
public:
	SpaceConstraintsList visibleConstraintsList;

	ConstraintTeacherMaxBuildingChangesPerWeekForm();
	~ConstraintTeacherMaxBuildingChangesPerWeekForm();

	bool filterOk(SpaceConstraint* ctr);

public slots:
	void constraintChanged(int index);
	void addConstraint();
	void modifyConstraint();
	void removeConstraint();

	void filterChanged();
};

#endif
